@@ -1,18 +1,15 @@
 """Agent registry services for discovery and tracking."""
 
-from .agent_registry import (
-    AgentRegistry,
-    AgentMetadata,
-    AgentTier,
-    AgentType,
-)
+from claude_mpm.core.unified_agent_registry import AgentMetadata, AgentTier, AgentType
+from claude_mpm.core.unified_agent_registry import UnifiedAgentRegistry as AgentRegistry
+
 from .deployed_agent_discovery import DeployedAgentDiscovery
 from .modification_tracker import (
-    AgentModificationTracker,
-    ModificationType,
-    ModificationTier,
     AgentModification,
+    AgentModificationTracker,
     ModificationHistory,
+    ModificationTier,
+    ModificationType,
 )
 
 __all__ = [
@@ -26,4 +23,4 @@ __all__ = [
     "ModificationTier",
     "AgentModification",
     "ModificationHistory",
-]
\ No newline at end of file
+]
